package vc.thinker.thirdpartyproxy;

import com.google.common.collect.Sets;
import lombok.AllArgsConstructor;
import lombok.Getter;
import vc.thinker.absctacts.protocolproxy.enums.IProtocolType;
import vc.thinker.web.validator.EnumValidate;

import java.util.Objects;
import java.util.Set;

/**
 * 第三方协议类型
 *
 * @author HeTongHao
 * @since 2021/7/9 16:20
 */
@Getter
@AllArgsConstructor
public enum ProtocolType implements IProtocolType, EnumValidate<String> {
    /**
     * 第三方协议类型
     */
    test("test", "测试"),
    /**
     * 中央空调
     */
    central_air_conditioning("central-air-conditioning","中央空调")
    ;

    static {
        int total = values().length;
        Set<ProtocolType> distinctSet = Sets.newHashSet(values());
        if (distinctSet.size() != total) {
            throw new IllegalArgumentException("协议编号有重复，请检查");
        }
    }

    /**
     * 协议编号
     */
    private final String code;
    /**
     * 协议名称
     */
    private final String name;


    @Override
    public boolean existValidate(String value) {
        if (value == null) {
            return false;
        }
        for (ProtocolType protocolType : ProtocolType.values()) {
            if (Objects.equals(protocolType.getCode(), value)) {
                return true;
            }
        }
        return false;
    }

}
